@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
@@ -54,46 +54,6 @@
 #ifndef XB_BACKEND
 #define XB_BACKEND
 
-/* unsigned int 64 for engine nodes work and display */
-#ifdef WIN32
-       /* I don't know the name for this type of other compiler
-        * If it not work, just modify here
-        * This is for MS Visual Studio
-        */
-       #ifdef _MSC_VER
-               #define u64 unsigned __int64
-               #define s64 signed __int64
-               #define u64Display "%I64u"
-               #define s64Display "%I64d"
-               #define u64Const(c) (c ## UI64)
-               #define s64Const(c) (c ## I64)
-       #else
-               /* place holder
-                * or dummy types for other compiler
-                * [HGM] seems that -mno-cygwin comple needs %I64?
-                */
-               #define u64 unsigned long long
-               #define s64 signed long long
-               #ifdef USE_I64
-                  #define u64Display "%I64u"
-                  #define s64Display "%I64d"
-               #else
-                  #define u64Display "%llu"
-                  #define s64Display "%lld"
-               #endif
-               #define u64Const(c) (c ## ULL)
-               #define s64Const(c) (c ## LL)
-       #endif
-#else
-       /* GNU gcc */
-       #define u64 unsigned long long
-       #define s64 signed long long
-       #define u64Display "%llu"
-       #define s64Display "%lld"
-       #define u64Const(c) (c ## ull)
-       #define s64Const(c) (c ## ll)
-#endif
-
 #include "lists.h"
 
 typedef int (*FileProc) P((FILE *f, int n, char *title));
