@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
@@ -215,7 +215,7 @@ void EnableNamedMenuItem P((char *menuRef, int state));
 typedef struct FrontEndProgramStats_TAG {
     int which;
     int depth;
-    unsigned long nodes;
+    u64 nodes;
     int score;
     int time;
     char * pv;
